==> nextcloud-app-tasks-0.13.6-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/sl.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Pomembno",
    "Today" : "Danes",
    "Week" : "Teden",
    "All" : "Vse",
    "Current" : "Trenutno",
    "Completed" : "Končano",
    "Tasks" : "Naloge",
    "The Tasks app for Nextcloud" : "Program Tasks za Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal, … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Po namestitvi programa se v meniju Nextcloud pojavi nova ikona Naloge. V vmesniku je mogoče dodati, izbrisati, ponovno urejati in prestavljati naloge, mogoče je dodati začetki in končni čas, opomnik, oznako pomembnosti in opombe. Naloge je prav tako mogoče dodeliti v souporabo. Podprto je tudi usklajevanje s koledarjem CalDaV (vsak seznam je povezan s koledarjem Nextcloud, prek tega pa ga je mogoče povezati z namiznim programom – Thunderbird, Evolution, KDE Kontact, iCal ... – z enostavnim dodajanjem povezave do oddaljenega koledarja) prek sistema CalDav. Naloge je mogoče prejeti tudi v zapisu ICS za vsak koledar.",
    "Add List…" : "Dodaj seznam ...",
    "New List" : "Nov seznam",
    "Cancel" : "Prekliči",
    "Save" : "Shrani",
    "The name \"{calendar}\" is already used." : "Ime »{calendar}« je že v uporabi.",
    "An empty name is not allowed." : "Prazno polje imena ni dovoljeno.",
    "Share with users or groups" : "Souporaba z uporabniki in skupinami",
    "No users or groups" : "Ni uporabnikov oziroma skupin",
    "can edit" : "lahko ureja",
    "Unshare with {displayName}" : "Odstrani souporabo z uporabnikom {displayName}",
    "Unable to delete the share." : "Ni mogoče izbrisati souporabe.",
    "Unable to change permissions." : "Ni mogoče spremeniti dovoljenj.",
    "Edit" : "Uredi",
    "Copy private link" : "Kopiraj zasebno povezavo",
    "Copied" : "Kopirano!",
    "Can not copy" : "Ni mogoče kopirati!",
    "Download" : "Prejmi",
    "Delete" : "Izbriši",
    "Unshare" : "Prekini souporabo",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Izbrisali boste koledar »{calendar}« in vse pripadajoče dogodke in naloge.",
    "This will unshare the calendar \"{calendar}\"." : "S tem bo onemogočena souporaba koledarja »{calendar}«.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Izbrisali boste seznam »{list}« in vse pripadajoče naloge.",
    "This will unshare the list \"{list}\"." : "S tem bo onemogočena souporaba seznama »{list}«.",
    "Calendar link copied to clipboard." : "Povezava koledarja je kopirana v odložišče.",
    "List link copied to clipboard." : "Povezava seznama je kopirana v odložišče.",
    "Calendar link could not be copied to clipboard." : "Povezave koledarja ni mogoče kopirati v odložišče.",
    "List link could not be copied to clipboard." : "Povezave seznama ni mogoče kopirati v odložišče.",
    "An error occurred, unable to delete the calendar." : "Prišlo je do napake, koledarja ni mogoče izbrisati.",
    "An error occurred, unable to delete the list." : "Prišlo je do napake, seznama ni mogoče izbrisati.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Koledar bo izbrisan čez {countdown} sekundo.","Koledar bo izbrisan čez {countdown} sekundi.","Koledar bo izbrisan čez {countdown} sekunde.","Koledar bo izbrisan čez {countdown} sekund."],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Souporaba koledarja bo onemogočena čez {countdown} sekundo.","Souporaba koledarja bo onemogočena čez {countdown} sekundi.","Souporaba koledarja bo onemogočena čez {countdown} sekunde.","Souporaba koledarja bo onemogočena čez {countdown} sekund."],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Seznam bo izbrisan čez {countdown} sekundo.","Seznam bo izbrisan čez {countdown} sekundi.","Seznam bo izbrisan čez {countdown} sekunde.","Seznam bo izbrisan čez {countdown} sekund."],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Souporaba seznama bo onemogočena čez {countdown} sekundo.","Souporaba seznama bo onemogočena čez {countdown} sekundi.","Souporaba seznama bo onemogočena čez {countdown} sekunde.","Souporaba seznama bo onemogočena čez {countdown} sekund."],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["V souporabi s skupno {num} odjemalcem","V souporabi s skupno {num} odjemalcema","V souporabi s skupno {num} odjemalci","V souporabi s skupno {num} odjemalci"],
    "Default list" : "Privzeti seznam",
    "Visibility of Smart Collections" : "Vidnost pametnih zbirk",
    "Hidden" : "Skrito",
    "Visible" : "Vidno",
    "Automatic" : "Samodejno",
    "Delete all completed tasks." : "Izbriši vse končane naloge.",
    "Delete completed tasks." : "Izbriši končane naloge.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Iz koledarja »{calendar}« so izbrisane vse končane naloge.",
    "No errors" : "Ni zaznanih napak",
    "Open your browser console for more details" : "Več podrobnosti je izpisanih v konzoli brskalnika",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Iz koledarja »{calendar}« boste zbrisali {taskCount} končano nalogo z vsemi podrejenimi.","Iz koledarja »{calendar}« boste zbrisali {taskCount} končani nalogi z vsemi podrejenimi.","Iz koledarja »{calendar}« boste zbrisali {taskCount} končane naloge z vsemi podrejenimi.","Iz koledarja »{calendar}« boste zbrisali {taskCount} končanih nalog z vsemi podrejenimi."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Ni mogoče izbrisati {failedCount} naloge.","Ni mogoče izbrisati {failedCount} nalog.","Ni mogoče izbrisati {failedCount} nalog.","Ni mogoče izbrisati {failedCount} nalog."],
    "Load all completed tasks." : "Naloži vse končane naloge.",
    "Change sort order" : "Spremeni vrstni red razvrščanja",
    "Relevance" : "Pomembnost",
    "Sort by completed state, due date, priority, start date and summary." : "Razvrsti po stanju opravljenosti, po datumu konca, prednosti, začetku in povzetku.",
    "Start date" : "Datum začetka",
    "Sort by start date and summary." : "Razvrsti po datumu začetka, nato po povzetku.",
    "Due date" : "Datum zapadlosti",
    "Sort by due date and summary." : "Razvrsti po datumu preteka, nato po povzetku.",
    "Created date" : "Ustvarjeno na",
    "Sort by created date and summary." : "Razvrsti po datumu ustvarjanja, nato po povzetku.",
    "Last modified" : "Nazadnje spremenjeno",
    "Sort by last-modified date and summary." : "Razvrsti po datumu zadnje spremembe, nato po povzetku.",
    "Completed date" : "Datum končanja",
    "Sort by completed date." : "Razvrsti po datumu končanja",
    "Priority" : "Prednost",
    "Sort by priority and summary." : "Razvrsti po prednosti, nato po povzetku.",
    "Alphabetically" : "Abecedno",
    "Sort by summary and priority." : "Razvrsti po povzetku, nato po prednosti.",
    "Manually" : "Ročno",
    "Sort by manual order." : "Razvrsti ročno",
    "Task is completed" : "Naloga je zaključena",
    "{complete} % completed" : "Končano je {complete} % naloge",
    "Add subtask" : "Dodaj podrejeno nalogo",
    "Show subtasks" : "Pokaži podrejene naloge",
    "Hide subtasks" : "Skrij podrejene naloge",
    "Show completed subtasks" : "Pokaži končane podrejene naloge",
    "Hide completed subtasks" : "Skrij končane podrejene naloge",
    "Delete task" : "Izbriši nalogo",
    "[Yesterday]" : "[Včeraj]",
    "[Today]" : "[Danes]",
    "[Tomorrow]" : "[Jutri]",
    "[Completed yesterday]" : "[Končano včeraj]",
    "[Completed today]" : "[Končano  danes]",
    "[Completed tomorrow]" : "[Konča se jutri]",
    "[Yesterday at] LT" : "[Včeraj ob] LT",
    "[Today at] LT" : "[Danes ob] LT",
    "[Tomorrow at] LT" : "[Jutri ob] LT",
    "L [at] LT" : "L [ob] LT",
    "[Completed yesterday at] LT" : "[Končano včeraj ob] LT",
    "[Completed today at] LT" : "[Končano danes ob] LT",
    "[Completed tomorrow at] LT" : "[Konča se jutri ob] LT",
    "[Completed] L [at] LT" : "[Končano] L [ob] LT",
    "Add a subtask to \"{task}\"…" : "Dodaj podrejeno nalogo k nalogi »{task}« ...",
    "An error occurred, unable to delete the task." : "Prišlo je do napake, naloge ni mogoče izbrisati.",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Naloga bo izbrisana čez {countdown} sekundo","Naloga bo izbrisana čez {countdown} sekundi","Naloga bo izbrisana čez {countdown} sekunde","Naloga bo izbrisana čez {countdown} sekund"],
    "Add a task to \"{task}\"…" : "Dodaj nalogo v seznam »{task}« ...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n končana naloga","%n končani nalogi","%n končane naloge","%n končanih nalog"],
    "Add an important task to \"{calendar}\"…" : "Dodaj pomembno nalogo v koledar »{calendar}« ...",
    "Add a task due today to \"{calendar}\"…" : "Dodaj nalogo, ki poteče danes, v koledar »{calendar}« ...",
    "Add a current task to \"{calendar}\"…" : "Dodaj trenutno nalogo v koledar »{calendar}« ...",
    "Add a task to \"{calendar}\"…" : "Dodaj nalogo v koledar »{calendar}« ...",
    "Tomorrow" : "Jutri",
    "Set start date" : "Nastavi datum začetka",
    "Set start time" : "Nastavi datum začetka",
    "Set due date" : "Nastavi datum preteka",
    "Set due time" : "Nastavi datum preteka",
    "All day" : "Ves dan",
    "Select a calendar" : "Izbor koledarja",
    "Select a classification" : "Izbor preikaza",
    "Select a status" : "Izbor stanja",
    "Select categories" : "Izbor kategorije",
    "Add this as a new category" : "Dodaj kot novo kategorijo",
    "Loading task from server." : "Poteka nalaganje nalog s strežnika.",
    "Task not found!" : "Naloge ni mogoče najti!",
    "When shared show full event" : "V souporabi pokaži poln dogodek",
    "When shared show only busy" : "V souporabi pokaži le, da je zasedeno",
    "When shared hide this event" : "V souporabi skrij ta dogodek",
    "Needs action" : "Zahteva odziv",
    "In process" : "V obdelavi",
    "Canceled" : "Preklicano",
    "[Starts today]" : "[Začne se danes]",
    "[Starts tomorrow]" : "[Začne se jutri]",
    "[Starts on] LL" : "[Začne se na] LL",
    "[Started yesterday]" : "[Začeto včeraj]",
    "[Started on] LL" : "[Začeto na] LL",
    "[Started today at] LT" : "[Začelo se je danes ob] LT",
    "[Starts today at] LT" : "[Začne se danes ob] LT",
    "[Starts tomorrow at] LT" : "[Začne se jutri ob] LT",
    "[Starts on] LL [at] LT" : "[Začne se na] LL [ob] LT",
    "[Started yesterday at] LT" : "[Začelo se je včeraj ob] LT",
    "[Started on] LL [at] LT" : "[Začeto na] LL [ob] LT",
    "[Due today]" : "[Poteče danes]",
    "[Due tomorrow]" : "[Poteče jutri]",
    "[Due on] LL" : "[Poteče na] LL",
    "[Was due yesterday]" : "[Poteklo je včeraj]",
    "[Was due on] LL" : "[Poteklo je na] LL",
    "[Was due today at] LT" : "[Poteklo je danes ob] LT",
    "[Due today at] LT" : "[Poteče danes ob] LT",
    "[Due tomorrow at] LT" : "[Poteče jutri ob] LT",
    "[Due on] LL [at] LT" : "[Poteče na] LL [ob] LT",
    "[Was due yesterday at] LT" : "[Poteklo je včeraj ob] LT",
    "[Was due on] LL [at] LT" : "[Poteklo je na] LL [ob] LT",
    "Last modified {date}" : "Nazadnje spremenjeno: {date}",
    "Created {date}" : "Ustvarjeno {date}",
    "Completed {date}" : "Končano {date}",
    "No priority assigned" : "Ni dodeljene prednosti",
    "Priority {priority}: high" : "Prednost {priority}: visoka",
    "Priority {priority}: medium" : "Prednost {priority}: običajna",
    "Priority {priority}: low" : "Prednost {priority}: nizka",
    "{percent} % completed" : "Končano je {percent} % naloge",
    "Successfully created the task." : "Naloga je uspešno ustvarjena.",
    "Could not delete the task." : "Naloge ni mogoče izbrisati.",
    "Synchronizing to the server." : "Poteka usklajevanje s strežnikom.",
    "Task successfully saved to server." : "Naloga je uspešno shranjena na strežnik.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Naloge ni mogoče posodobiti, ker je bila spremenjena na strežniku. Nalogo je treba osvežiti, vse krajevne spremembe pa bodo izgubljene.",
    "Could not update the task." : "Naloge ni mogoče posodobiti.",
    "Successfully updated the task." : "Naloga je uspešno posodobljena.",
    "Task successfully moved to new calendar." : "Naloga je uspešno premaknjena v nov koledar.",
    "An error occurred" : "Prišlo je do napake."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-app-tasks-0.14.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/sl.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Prihajajoče naloge",
    "Important" : "Pomembno",
    "Today" : "Danes",
    "Week" : "Teden",
    "All" : "Vse",
    "Current" : "Trenutno",
    "Completed" : "Končano",
    "Tasks" : "Naloge",
    "The Tasks app for Nextcloud" : "Program Tasks za Nextcloud",
    "Default list" : "Privzeti seznam",
    "Visibility of Smart Collections" : "Vidnost pametnih zbirk",
    "Hidden" : "Skrito",
    "Visible" : "Vidno",
    "Automatic" : "Samodejno",
    "Share with users or groups" : "Souporaba z uporabniki in skupinami",
    "No users or groups" : "Ni uporabnikov oziroma skupin",
    "Can edit" : "Lahko ureja",
    "Unshare with {displayName}" : "Odstrani souporabo z uporabnikom {displayName}",
    "Unable to delete the share." : "Ni mogoče izbrisati souporabe.",
    "Unable to change permissions." : "Ni mogoče spremeniti dovoljenj.",
    "Edit" : "Uredi",
    "Copy private link" : "Kopiraj zasebno povezavo",
    "Copied" : "Kopirano!",
    "Cannot copy" : "Predmeta ni mogoče kopirati",
    "Delete" : "Izbriši",
    "Unshare" : "Prekini souporabo",
    "Cancel" : "Prekliči",
    "Save" : "Shrani",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Izbrisali boste koledar »{calendar}« in vse pripadajoče dogodke in naloge.",
    "This will unshare the calendar \"{calendar}\"." : "S tem bo onemogočena souporaba koledarja »{calendar}«.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Izbrisali boste seznam »{list}« in vse pripadajoče naloge.",
    "This will unshare the list \"{list}\"." : "S tem bo onemogočena souporaba seznama »{list}«.",
    "Calendar link copied to clipboard." : "Povezava koledarja je kopirana v odložišče.",
    "List link copied to clipboard." : "Povezava seznama je kopirana v odložišče.",
    "Calendar link could not be copied to clipboard." : "Povezave koledarja ni mogoče kopirati v odložišče.",
    "List link could not be copied to clipboard." : "Povezave seznama ni mogoče kopirati v odložišče.",
    "The name \"{calendar}\" is already used." : "Ime »{calendar}« je že v uporabi.",
    "An empty name is not allowed." : "Prazno polje imena ni dovoljeno.",
    "An error occurred, unable to delete the calendar." : "Prišlo je do napake, koledarja ni mogoče izbrisati.",
    "An error occurred, unable to delete the list." : "Prišlo je do napake, seznama ni mogoče izbrisati.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Koledar bo izbrisan čez {countdown} sekundo.","Koledar bo izbrisan čez {countdown} sekundi.","Koledar bo izbrisan čez {countdown} sekunde.","Koledar bo izbrisan čez {countdown} sekund."],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Souporaba koledarja bo onemogočena čez {countdown} sekundo.","Souporaba koledarja bo onemogočena čez {countdown} sekundi.","Souporaba koledarja bo onemogočena čez {countdown} sekunde.","Souporaba koledarja bo onemogočena čez {countdown} sekund."],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Seznam bo izbrisan čez {countdown} sekundo.","Seznam bo izbrisan čez {countdown} sekundi.","Seznam bo izbrisan čez {countdown} sekunde.","Seznam bo izbrisan čez {countdown} sekund."],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Souporaba seznama bo onemogočena čez {countdown} sekundo.","Souporaba seznama bo onemogočena čez {countdown} sekundi.","Souporaba seznama bo onemogočena čez {countdown} sekunde.","Souporaba seznama bo onemogočena čez {countdown} sekund."],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["V souporabi s skupno {num} odjemalcem","V souporabi s skupno {num} odjemalcema","V souporabi s skupno {num} odjemalci","V souporabi s skupno {num} odjemalci"],
    "Trash bin" : "Smetnjak",
    "Loading deleted calendars, tasks and events." : "Poteka nalaganje koledarjev, nalog in dogodkov.",
    "You do not have any deleted calendars, tasks or events." : "Ni nobenih izbrisanih koledarjev, nalog ali dogodkov",
    "Name" : "Ime",
    "Deleted" : "Izbrisano",
    "Restore" : "Obnovi",
    "Delete permanently" : "Izbriši trajno",
    "Empty trash bin" : "Izprazni smeti",
    "Untitled item" : "Neimenovan predmet",
    "Could not load deleted calendars and objects" : "Ni mogoče naložiti izbrisanih koledarjev in predmetov",
    "Could not delete calendar or event" : "Ni mogoče izbrisati koledarja ali dogodka",
    "Could not restore calendar or event" : "Ni mogoče obnoviti koledarja ali dogodka",
    "Do you really want to empty the trash bin?" : "Ali zares želite izprazniti smetnjak?",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Predmeti v smetnjaku se izbrišejo po {numDays} dnevu","Predmeti v smetnjaku se izbrišejo po {numDays} dnevih","Predmeti v smetnjaku se izbrišejo po {numDays} dnevih","Predmeti v smetnjaku se izbrišejo po {numDays} dnevih"],
    "Set date" : "Nastavi datum",
    "Set time" : "Nastavi čas",
    "Delete date" : "Izbriši datum",
    "Click here to add a note." : "Kliknite za dodajanje sporočila.",
    "Set value" : "Nastavi vrednost",
    "Delete value" : "Izbriši vrednost",
    "Add this as a new tag" : "Dodaj kot novo oznako",
    "No tag available. Create one!" : "Ni razpoložljivih oznak. Ustvarite jih!",
    "Delete all completed tasks." : "Izbriši vse končane naloge.",
    "Delete completed tasks." : "Izbriši končane naloge.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Iz koledarja »{calendar}« so izbrisane vse končane naloge.",
    "No errors" : "Ni zaznanih napak",
    "Open your browser console for more details" : "Več podrobnosti je izpisanih v konzoli brskalnika",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Iz koledarja »{calendar}« boste zbrisali {taskCount} končano nalogo z vsemi podrejenimi.","Iz koledarja »{calendar}« boste zbrisali {taskCount} končani nalogi z vsemi podrejenimi.","Iz koledarja »{calendar}« boste zbrisali {taskCount} končane naloge z vsemi podrejenimi.","Iz koledarja »{calendar}« boste zbrisali {taskCount} končanih nalog z vsemi podrejenimi."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Ni mogoče izbrisati {failedCount} naloge.","Ni mogoče izbrisati {failedCount} nalog.","Ni mogoče izbrisati {failedCount} nalog.","Ni mogoče izbrisati {failedCount} nalog."],
    "Add an important task to \"{calendar}\"…" : "Dodaj pomembno nalogo v koledar »{calendar}« ...",
    "Add a task due today to \"{calendar}\"…" : "Dodaj nalogo, ki poteče danes, v koledar »{calendar}« ...",
    "Add a current task to \"{calendar}\"…" : "Dodaj trenutno nalogo v koledar »{calendar}« ...",
    "Add a task to \"{calendar}\"…" : "Dodaj nalogo v koledar »{calendar}« ...",
    "Load all completed tasks." : "Naloži vse končane naloge.",
    "Change sort order" : "Spremeni vrstni red razvrščanja",
    "Relevance" : "Pomembnost",
    "Sort by completed state, due date, priority, start date and summary." : "Razvrsti po stanju opravljenosti, po datumu konca, prednosti, začetku in povzetku.",
    "Start date" : "Datum začetka",
    "Sort by start date and summary." : "Razvrsti po datumu začetka, nato po povzetku.",
    "Due date" : "Datum zapadlosti",
    "Sort by due date and summary." : "Razvrsti po datumu preteka, nato po povzetku.",
    "Created date" : "Ustvarjeno na",
    "Sort by created date and summary." : "Razvrsti po datumu ustvarjanja, nato po povzetku.",
    "Last modified" : "Nazadnje spremenjeno",
    "Sort by last-modified date and summary." : "Razvrsti po datumu zadnje spremembe, nato po povzetku.",
    "Completed date" : "Datum končanja",
    "Sort by completed date." : "Razvrsti po datumu končanja",
    "Priority" : "Prednost",
    "Sort by priority and summary." : "Razvrsti po prednosti, nato po povzetku.",
    "Alphabetically" : "Abecedno",
    "Sort by summary and priority." : "Razvrsti po povzetku, nato po prednosti.",
    "Manually" : "Ročno",
    "Sort by manual order." : "Razvrsti ročno",
    "{complete} % completed" : "Končano je {complete} % naloge",
    "Task has hidden subtasks" : "Naloga ima skrite podrejene naloge",
    "Task is pinned" : "Naloga je pripeta na vrh",
    "Task has a note" : "Naloga ima vpisano opombo",
    "Add subtask" : "Dodaj podrejeno nalogo",
    "Show subtasks" : "Pokaži podrejene naloge",
    "Hide subtasks" : "Skrij podrejene naloge",
    "Show closed subtasks" : "Pokaži zaprte podrejene naloge",
    "Hide closed subtasks" : "Skrij zaprte podrejene naloge",
    "Delete task" : "Izbriši nalogo",
    "Toggle starred" : "Preklopi oznako z zvezdico",
    "[Yesterday]" : "[Včeraj]",
    "[Today]" : "[Danes]",
    "[Tomorrow]" : "[Jutri]",
    "[Completed yesterday]" : "[Končano včeraj]",
    "[Completed today]" : "[Končano  danes]",
    "[Completed tomorrow]" : "[Konča se jutri]",
    "[Yesterday at] LT" : "[Včeraj ob] LT",
    "[Today at] LT" : "[Danes ob] LT",
    "[Tomorrow at] LT" : "[Jutri ob] LT",
    "L [at] LT" : "L [ob] LT",
    "[Completed yesterday at] LT" : "[Končano včeraj ob] LT",
    "[Completed today at] LT" : "[Končano danes ob] LT",
    "[Completed tomorrow at] LT" : "[Konča se jutri ob] LT",
    "[Completed] L [at] LT" : "[Končano] L [ob] LT",
    "Add a subtask to \"{task}\"…" : "Dodaj podrejeno nalogo k nalogi »{task}« ...",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Naloga bo izbrisana čez {countdown} sekundo","Naloga bo izbrisana čez {countdown} sekundi","Naloga bo izbrisana čez {countdown} sekunde","Naloga bo izbrisana čez {countdown} sekund"],
    "Task is completed" : "Naloga je zaključena",
    "Create a new task" : "Ustvari novo nalogo",
    "Task summary" : "Povzetek naloge",
    "Create task" : "Ustvari nalogo",
    "Creating the new task…" : "Poteka ustvarjanje nove naloge ...",
    "\"{task}\" was added to \"{calendar}\"" : "Naloga »{task}« je dodana v koledar »{calendar}«.",
    "Open task" : "Odpri nalogo",
    "Close" : "Zapri",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n končana naloga","%n končani nalogi","%n končane naloge","%n končanih nalog"],
    "Tomorrow" : "Jutri",
    "Add List…" : "Dodaj seznam ...",
    "New List" : "Nov seznam",
    "All day" : "Ves dan",
    "Unpin" : "Odpni",
    "Pin" : "Pripni",
    "Show in Calendar" : "Pokaži v koledarju",
    "Edit title" : "Uredi naslov",
    "Details" : "Podrobnosti",
    "Select a classification" : "Izbor preikaza",
    "Select a status" : "Izbor stanja",
    "Select tags" : "Izbor oznak",
    "Notes" : "Opombe",
    "Reminders" : "Opomniki",
    "Repeat" : "Ponovi",
    "When shared show full event" : "V souporabi pokaži poln dogodek",
    "When shared show only busy" : "V souporabi pokaži le, da je zasedeno",
    "When shared hide this event" : "V souporabi skrij ta dogodek",
    "[Completed] L" : "[Končano:] L",
    "[Completed last] dddd [at] LT" : "[Končano:] dddd [ob] LT",
    "[Completed] dddd [at] LT" : "[Končano:] dddd [ob] LT",
    "[Last modified yesterday at] LT" : "[Nazadnje spremenjeno včeraj ob] LT",
    "[Last modified today at] LT" : "[Nazadnje spremenjeno danes ob] LT",
    "[Last modified] L" : "[Nazadnje spremenjeno:] L",
    "[Last modified last] dddd [at] LT" : "[Nazadnje spremenjeno:] dddd [ob] LT",
    "[Last modified] dddd [at] LT" : "[Nazadnje spremenjeno:] dddd [ob] LT",
    "[Created yesterday at] LT" : "[Ustvarjeno včeraj ob] LT",
    "[Created today at] LT" : "[Ustvarjeno danes ob] LT",
    "[Created] L" : "[Ustvarjeno:] L",
    "[Created last] dddd [at] LT" : "[Ustvarjeno:] dddd [ob] LT",
    "[Created] dddd [at] LT" : "[Ustvarjeno:] dddd [ob] LT",
    "Needs action" : "Zahteva odziv",
    "In process" : "V obdelavi",
    "Canceled" : "Preklicano",
    "Clear status" : "Počisti stanje",
    "Loading task from server." : "Poteka nalaganje nalog s strežnika.",
    "Task not found!" : "Naloge ni mogoče najti!",
    "[Starts today]" : "[Začne se danes]",
    "[Starts tomorrow]" : "[Začne se jutri]",
    "[Starts on] LL" : "[Začne se na] LL",
    "[Started yesterday]" : "[Začeto včeraj]",
    "[Started on] LL" : "[Začeto na] LL",
    "[Started today at] LT" : "[Začelo se je danes ob] LT",
    "[Starts today at] LT" : "[Začne se danes ob] LT",
    "[Starts tomorrow at] LT" : "[Začne se jutri ob] LT",
    "[Starts on] LL [at] LT" : "[Začne se na] LL [ob] LT",
    "[Started yesterday at] LT" : "[Začelo se je včeraj ob] LT",
    "[Started on] LL [at] LT" : "[Začeto na] LL [ob] LT",
    "Set start date" : "Nastavi datum začetka",
    "[Due today]" : "[Poteče danes]",
    "[Due tomorrow]" : "[Poteče jutri]",
    "[Due on] LL" : "[Poteče na] LL",
    "[Was due yesterday]" : "[Poteklo je včeraj]",
    "[Was due on] LL" : "[Poteklo je na] LL",
    "[Was due today at] LT" : "[Poteklo je danes ob] LT",
    "[Due today at] LT" : "[Poteče danes ob] LT",
    "[Due tomorrow at] LT" : "[Poteče jutri ob] LT",
    "[Due on] LL [at] LT" : "[Poteče na] LL [ob] LT",
    "[Was due yesterday at] LT" : "[Poteklo je včeraj ob] LT",
    "[Was due on] LL [at] LT" : "[Poteklo je na] LL [ob] LT",
    "Set due date" : "Nastavi datum preteka",
    "Priority {priority}: low" : "Prednost {priority}: nizka",
    "Priority {priority}: medium" : "Prednost {priority}: običajna",
    "Priority {priority}: high" : "Prednost {priority}: visoka",
    "No priority assigned" : "Ni dodeljene prednosti",
    "{percent} % completed" : "Končano je {percent} % naloge",
    "No upcoming tasks" : "Ni prihajajočih nalog",
    "upcoming tasks" : "prihajajoče naloge",
    "No tasks today" : "Za danes ni dodeljenih nalog",
    "Mark as done" : "Označi kot končano",
    "No due date assigned" : "Ni dodeljenega datuma preteka",
    "[Due yesterday]" : "[Preteklo včeraj]",
    "[Due] L" : "[Poteče na] L",
    "[Due yesterday at] LT" : "[Poteklo je včeraj ob] LT",
    "[Due] L [at] LT" : "[Poteče na] L [ob] LT",
    "Successfully created the task." : "Naloga je uspešno ustvarjena.",
    "Could not delete the task." : "Naloge ni mogoče izbrisati.",
    "Synchronizing to the server." : "Poteka usklajevanje s strežnikom.",
    "Task successfully saved to server." : "Naloga je uspešno shranjena na strežnik.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Naloge ni mogoče posodobiti, ker je bila spremenjena na strežniku. Nalogo je treba osvežiti, vse krajevne spremembe pa bodo izgubljene.",
    "Could not update the task." : "Naloge ni mogoče posodobiti.",
    "Successfully updated the task." : "Naloga je uspešno posodobljena.",
    "Task successfully moved to new calendar." : "Naloga je uspešno premaknjena v nov koledar.",
    "An error occurred" : "Prišlo je do napake.",
    "Create a task" : "Ustvari nalogo",
    "Message from {author} in {conversationName}" : "{author} objavi sporočilo v pogovoru {conversationName}"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
